@@ -19,6 +19,7 @@
 
 #include "DataType.h"
 #include "DataStructure.h"
+#include "DocumentManager.h"
 #include <boost/weak_ptr.hpp>
 
 #include <KDebug>
@@ -63,7 +64,6 @@ DataTypePtr DataType::create(Document* document, int identifier)
     DataTypePtr pi(new DataType(document, identifier));
     pi->d->q = pi;
     pi->addProperty("name", "");
-
     return pi;
 }
 
@@ -115,7 +115,7 @@ KIcon DataType::icon() const
         svgFile.open(QIODevice::ReadOnly | QIODevice::Text);
 
         QXmlStreamReader reader(&svgFile);
-        QSvgRenderer *renderer = Document::sharedRenderer(svgFile.fileName());
+        QSvgRenderer *renderer = DocumentManager::self().sharedRenderer(svgFile.fileName());
         while (!reader.atEnd()) {
             reader.readNext();
             if (!reader.attributes().hasAttribute("id")) {
@@ -191,7 +191,7 @@ void DataType::renameProperty(const QString& oldName, const QString& newName)
 
 QStringList DataType::properties() const
 {
-    return d->_propertyList.keys();
+    return QStringList(d->_propertyList.keys());
 }
 
 QVariant DataType::propertyDefaultValue(const QString& name) const
